@@ -32,7 +32,7 @@
  * Author: Federico Mena <federico@nuclecu.unam.mx>
  */
 
-#include "config.h"
+#include "gchempaint-config.h"
 #include <math.h>
 #include <string.h>
 #include <libart_lgpl/art_vpath.h>
